# gozerbot/datadir.py
#
#

""" this is where the datadir lives """

__copyright__ = 'this file is in the public domain'

import os

datadir = 'gozerdata'

# old 0.4 compat shim
if os.path.isfile('data.new/config'):
    datadir = 'data.new'
elif os.path.isfile('data/config'):
    datadir = 'data'

def makedirs():
    """ create datadir if it nog already exists """
    if not os.path.isdir(datadir):
        os.mkdir(datadir)
    if not os.path.isdir(datadir + '/userstates/'):
        os.mkdir(datadir + '/userstates/')
